Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(832)

Unified Diff: Source/core/dom/Element.h

Issue 141013010: Rename bindingFoo to fooForBindings (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | Source/core/dom/Element.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/dom/Element.h
diff --git a/Source/core/dom/Element.h b/Source/core/dom/Element.h
index abc6d8d9c626125fa10618a765abe6e5cf7b55b4..054d6cbab77fb768de0d650f5114e308c0e75fbc 100644
--- a/Source/core/dom/Element.h
+++ b/Source/core/dom/Element.h
@@ -175,8 +175,8 @@ public:
int offsetHeight();
// FIXME: Replace uses of offsetParent in the platform with calls
- // to the render layer and merge bindingsOffsetParent and offsetParent.
- Element* bindingsOffsetParent();
+ // to the render layer and merge offsetParentForBindings and offsetParent.
+ Element* offsetParentForBindings();
Element* offsetParent();
int clientLeft();
« no previous file with comments | « no previous file | Source/core/dom/Element.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698